@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -601,9 +601,13 @@ def mountEcryptfs(userName, userPwd, userDir):
 def isBootstrapDataOnly(directory):
     """
     Каталог содержит только сертификат, созданный командой cl-core
+    а так же настроенные симлинки на .face
     """
     userCalculate = path.join(directory, ".calculate")
-    return (set(listDirectory(directory)) == {".calculate"} and
+    return (set(listDirectory(directory)) <= {
+        ".calculate",
+        ".face",
+        ".face.icon"} and
             set(listDirectory(userCalculate)) == {"client_cert"})
 
 
